[−][src]Enum unicode_types::shavian::Shavian
An enum to represent all characters in the Shavian block.
Variants
LetterPeep\u{10450}: '𐑐'
LetterTot\u{10451}: '𐑑'
LetterKick\u{10452}: '𐑒'
LetterFee\u{10453}: '𐑓'
LetterThigh\u{10454}: '𐑔'
LetterSo\u{10455}: '𐑕'
LetterSure\u{10456}: '𐑖'
LetterChurch\u{10457}: '𐑗'
LetterYea\u{10458}: '𐑘'
LetterHung\u{10459}: '𐑙'
LetterBib\u{1045a}: '𐑚'
LetterDead\u{1045b}: '𐑛'
LetterGag\u{1045c}: '𐑜'
LetterVow\u{1045d}: '𐑝'
LetterThey\u{1045e}: '𐑞'
LetterZoo\u{1045f}: '𐑟'
LetterMeasure\u{10460}: '𐑠'
LetterJudge\u{10461}: '𐑡'
LetterWoe\u{10462}: '𐑢'
LetterHaDashHa\u{10463}: '𐑣'
LetterLoll\u{10464}: '𐑤'
LetterMime\u{10465}: '𐑥'
LetterIf\u{10466}: '𐑦'
LetterEgg\u{10467}: '𐑧'
LetterAsh\u{10468}: '𐑨'
LetterAdo\u{10469}: '𐑩'
LetterOn\u{1046a}: '𐑪'
LetterWool\u{1046b}: '𐑫'
LetterOut\u{1046c}: '𐑬'
LetterAh\u{1046d}: '𐑭'
LetterRoar\u{1046e}: '𐑮'
LetterNun\u{1046f}: '𐑯'
LetterEat\u{10470}: '𐑰'
LetterAge\u{10471}: '𐑱'
LetterIce\u{10472}: '𐑲'
LetterUp\u{10473}: '𐑳'
LetterOak\u{10474}: '𐑴'
LetterOoze\u{10475}: '𐑵'
LetterOil\u{10476}: '𐑶'
LetterAwe\u{10477}: '𐑷'
LetterAre\u{10478}: '𐑸'
LetterOr\u{10479}: '𐑹'
LetterAir\u{1047a}: '𐑺'
LetterErr\u{1047b}: '𐑻'
LetterArray\u{1047c}: '𐑼'
LetterEar\u{1047d}: '𐑽'
LetterIan\u{1047e}: '𐑾'
Methods
impl Shavian[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case